/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * MessageResponse.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * Container object used to pass the results of actions performed by 
 * the MessageServer Servlet back to the MessageNow Applet
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 
 
package Demos.MessageDemo.MessageServer.client;


/**
 * <p>Container class used to carry the results of the MessageServer's 
 * actions back to the applet.
 * 
 * <p>The text responses are placed within array that can be accessed via
 * the <em>getResponses</em> method.
 * 
 * @author Steve Ims
 * @see MessageServer
 * @see MessageClient
 * @see MessageNow
 */
public class MessageResponse {
    boolean     _success;
    String []   _response;


    /**
     * Constructor for successful response.
     */
    MessageResponse(boolean success, String [] successResponses) {
        _success  = success;
        _response = new String[successResponses.length];
        
        System.arraycopy(successResponses, 0, 
                         _response, 0, successResponses.length);
    }

    
    /** 
     * Constructor for failed response.
     */
    MessageResponse(boolean success, String failedResponse) {
        this(success, convertStringToStringArray(failedResponse));
    }


    public boolean isSuccessful() {
        return(_success);
    }


    /**
     * Get text responses to message attemps
     * @return array of strings for each recipient a message was intended for
     */
    public String [] getResponses() {
        return(_response);
    }


    static String [] convertStringToStringArray(String s) {
        String [] array = new String[1];
        array[0] = s;

        return(array);
    }
}
