/*================================================================== 
 * Licensed Materials - Property of IBM 
 * IBM SecureWay On Demand Client/Server 
 * (c) Copyright IBM Corp. 1999  All rights reserved. 
 * 
 * US Government Users Restricted Rights - Use, duplication or 
 * disclosure restricted by GSA ADP Schedule Contract with IBM 
 * Corp. 
 * 
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is 
 * sample code created by IBM Corporation.  This sample code is 
 * not part of any standard or IBM product and is provided to you 
 * solely for the purpose of assisting you in the development of 
 * your applications.  The code is provided "AS IS", without 
 * warranty of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if they have 
 * been advised of the possibility of such damages. 
 ******************************************************************** 
 * UserProfile.java
 *
 * Demo: Pager Messaging 
 *
 * Purpose:
 * Simple applet to allow a user to edit some of their
 * preferences associated with the messaging demo.
 * i.e. Their pager type, and pin number.
 ******************************************************************** 
 * Change History: 
 ******************************************************************** 
 * 
 *  REASON   DATE     ORIGIN     DESCRIPTION 
 *  -------- ------   ------     ----------- 
 *  new      052599   Steve Ims  New code 
 *===================================================================*/ 

package Demos.MessageDemo.UserProfile;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import javax.swing.*;
import javax.swing.border.*;

import com.ibm.managed.preference.*;
import com.ibm.managed.resource.*;

import Demos.MessageDemo.MessageServer.*;

import com.ms.security.*;  
import netscape.security.*;


/**
 * <p>This class illustrates the use of the <b>PreferenceSet</b>
 * class in order to modify individual user preferences.
 * The Applet presents a simple form that allows the user to 
 * directly modify some of their preferences, such as their 
 * preferred notification method.
 * 
 * <p>This applet demonstrates a couple of features of ODS:
 * <ul>
 *      <li> How one can control which properties a user will 
 *           be allowed to modify directly.
 *      <li> How to go about obtaining, modifying, and saving user
 *           preferences through the use of the <b>PreferenceContext</b>
 *           and <b>PreferenceSet</b> classes.
 * </ul>
 *
 * @author Steve Ims
 * @see MessageNow
 */
public class UserProfile extends JApplet {
       
    // GUI Components
    JTextField _officeLocation;
    JTextField _mailingStreet;
    JTextField _mailingCity;
    JTextField _mailingState;
    JTextField _mailingZipCode;

    JTextField _workPhone;
    JTextField _externalPhone;

    JTextField _faxNumber;

    JTextField _emailAddress;

    JComboBox  _pagerType;
    JTextField _pagerPin;

    JTextField _backupUserId;

    JRadioButton _bPager;
    JRadioButton _bBackup;
    JRadioButton _bEmail;
    JRadioButton _bFax;
    JRadioButton _bNone;
    ButtonGroup  _contactGroup;

    JButton _bSave;

    // Preference variables
    PreferenceContext _userPrefContext;
    PreferenceSet _prefs;


    /**
     * This method force the user to login at applet startup, and
     * also uses the PreferenceSet class to save a working
     * copy of the user preferences.
     */
    public void start() {
        try {
            // Netscape permissions
            PrivilegeManager.enablePrivilege("UniversalConnect");
            
            // IE permissions
            PolicyEngine.assertPermission(PermissionID.NETIO); 
            
            System.out.println("getting prefs for context "
                               + MessageConstants.PREFERENCE_CONTEXT);

            // These API calls force the applet user to login
            _userPrefContext 
                = PreferenceContext.getInitialContext(MessageConstants.PREFERENCE_CONTEXT);
            _userPrefContext.refresh();

            _prefs = new PreferenceSet();
            _prefs.load(_userPrefContext);

        } catch(ResourceException x) {
            x.printStackTrace();
        }

        getContentPane().add(new JScrollPane(createPanel()));
    }


    /**
     * Create the simple user interface form to edit preferences.
     * The method makes several calls to getStringOrBlank in order
     * to fill in the form with the current preferences, which are
     * located in _prefs.
     */
    JComponent createPanel() {
        JPanel p = new JPanel();
        p.setLayout(new GridBagLayout());

        GridBagConstraints gbc = new GridBagConstraints();
        gbc.gridx = 0;
        gbc.gridy = GridBagConstraints.RELATIVE;
        gbc.fill = GridBagConstraints.HORIZONTAL;
        gbc.weightx = 1.0;

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(5, 2));

            pp.add(new JLabel("Office"));
            _officeLocation 
                = new JTextField(getStringOrBlank(MessageConstants.OFFICE_LOCATION));
            pp.add(_officeLocation);

            pp.add(new JLabel("Mailing Street"));
            _mailingStreet
                = new JTextField(getStringOrBlank(MessageConstants.MAILING_STREET));
            pp.add(_mailingStreet);

            pp.add(new JLabel("Mailing City"));
            _mailingCity
                = new JTextField(getStringOrBlank(MessageConstants.MAILING_CITY));
            pp.add(_mailingCity);

            pp.add(new JLabel("Mailing State"));
            _mailingState
                = new JTextField(getStringOrBlank(MessageConstants.MAILING_STATE));
            pp.add(_mailingState);

            pp.add(new JLabel("Mailing Zip Code"));
            _mailingZipCode
                = new JTextField(getStringOrBlank(MessageConstants.MAILING_ZIPCODE));
            pp.add(_mailingZipCode);

            pp.setBorder(BorderFactory.createTitledBorder("Location"));
            pp.setBackground(new Color(0xa0, 0xa0, 0xa0));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(2, 2));

            pp.add(new JLabel("Work Phone"));
            _workPhone = new JTextField(getStringOrBlank(MessageConstants.WORK_PHONE));
            pp.add(_workPhone);

            pp.add(new JLabel("External Phone"));
            _externalPhone = new JTextField(getStringOrBlank(MessageConstants.EXTERNAL_PHONE));
            pp.add(_externalPhone);

            pp.setBorder(BorderFactory.createTitledBorder("Phone"));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(1, 2));

            pp.add(new JLabel("Fax Number"));
            _faxNumber = new JTextField(getStringOrBlank(MessageConstants.EXTERNAL_FAX));
            pp.add(_faxNumber);
            
            pp.setBorder(BorderFactory.createTitledBorder("Fax"));
            pp.setBackground(new Color(0xa0, 0xa0, 0xa0));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(1, 2));

            pp.add(new JLabel("Email address"));
            _emailAddress = new JTextField(getStringOrBlank(MessageConstants.EMAIL_ADDRESS));
            pp.add(_emailAddress);

            pp.setBorder(BorderFactory.createTitledBorder("Email"));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(2, 2));

            pp.add(new JLabel("Pager Type"));

            _pagerType = new JComboBox();
            String selectedPager = getStringOrBlank(MessageConstants.PAGER_TYPE);
            if(selectedPager.equals("")) {
                selectedPager = new String("None");
            }

            _pagerType.addItem("None");
            if(selectedPager.equals("None")) {
                _pagerType.setSelectedIndex(0);
            }
            
            String [] pagers = MessageConstants.SUPPORTED_PAGERS;
            for(int i=0; i<pagers.length; i++) {
                _pagerType.addItem(pagers[i]);
                if(selectedPager.equals(pagers[i])) {
                    _pagerType.setSelectedIndex(i+1);
                }
            }

            pp.add(_pagerType);

            pp.add(new JLabel("PIN"));
            _pagerPin = new JTextField(getStringOrBlank(MessageConstants.PAGER_PIN));
            pp.add(_pagerPin);

            pp.setBorder(BorderFactory.createTitledBorder("Pager"));
            pp.setBackground(new Color(0xa0, 0xa0, 0xa0));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            pp.setLayout(new GridLayout(1, 2));

            pp.add(new JLabel("Userid of backup person"));
            _backupUserId = new JTextField(getStringOrBlank(MessageConstants.BACKUP_USERID));
            pp.add(_backupUserId);

            pp.setBorder(BorderFactory.createTitledBorder("Backup Contact"));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();
            _contactGroup = new ButtonGroup();

            String selectedBackup = getStringOrBlank(MessageConstants.IMMEDIATE_CONTACT);
            if(selectedBackup.equals("")) {
                selectedBackup = new String("None");
            }

            System.out.println("selectedBackup = " + selectedBackup);

            _bPager = new JRadioButton("Pager");
            _bPager.setActionCommand(MessageConstants.NOTIFY_PAGER);
            if(selectedBackup.equals(_bPager.getActionCommand())) {
                _bPager.setSelected(true);
            }
            _contactGroup.add(_bPager);
            pp.add(_bPager);

            _bBackup = new JRadioButton("Backup");
            _bBackup.setActionCommand(MessageConstants.NOTIFY_BACKUP);
            if(selectedBackup.equals(_bBackup.getActionCommand())) {
                _bBackup.setSelected(true);
            }
            _contactGroup.add(_bBackup);
            pp.add(_bBackup);

            // _bEmail = new JRadioButton("Email");   // sdi
            _bEmail = new JRadioButton("Email*");     // sdi
            _bEmail.setActionCommand(MessageConstants.NOTIFY_EMAIL);
            if(selectedBackup.equals(_bEmail.getActionCommand())) {
                _bEmail.setSelected(true);
            }
            _bEmail.setEnabled(false);                // sdi            
            _contactGroup.add(_bEmail);
            pp.add(_bEmail);

            // _bFax = new JRadioButton("Fax");       // sdi
            _bFax = new JRadioButton("Fax*");         // sdi
            _bFax.setActionCommand(MessageConstants.NOTIFY_FAX);
            if(selectedBackup.equals(_bFax.getActionCommand())) {
                _bFax.setSelected(true);
            }
            _bFax.setEnabled(false);                  // sdi            
            _contactGroup.add(_bFax);
            pp.add(_bFax);

            _bNone = new JRadioButton("None");
            _bNone.setActionCommand(MessageConstants.NOTIFY_NONE);
            if(selectedBackup.equals(_bNone.getActionCommand())) {
                _bNone.setSelected(true);
            }
            _contactGroup.add(_bNone);
            pp.add(_bNone);

            pp.add(new Label("* = not implemented")); // sdi

            pp.setBorder(BorderFactory.createTitledBorder("Immediate Contact"));
            pp.setBackground(new Color(0xa0, 0xa0, 0xa0));

            p.add(pp, gbc);
        }

        {
            JPanel pp = new JPanel();

            _bSave = new JButton("Save");
            _bSave.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    saveProfile();
                }
            });
            
            pp.add(_bSave);

            p.add(pp, gbc);
        }

        return(p);
    }   // end creatpanel


    /**
     * Save the modified preferences back to the PreferenceContext.
     * This method makes the changes made permanent.
     */
    void saveProfile() {
        
        // Save the preference changes made in the user interface in 
        //  the working copy
        
        _prefs.put(MessageConstants.OFFICE_LOCATION, 
                   _officeLocation.getText());

        _prefs.put(MessageConstants.MAILING_STREET,
                   _mailingStreet.getText());

        _prefs.put(MessageConstants.MAILING_CITY,
                   _mailingCity.getText());

        _prefs.put(MessageConstants.MAILING_STATE,
                   _mailingState.getText());

        _prefs.put(MessageConstants.MAILING_ZIPCODE,
                   _mailingZipCode.getText());

        _prefs.put(MessageConstants.WORK_PHONE,
                   _workPhone.getText());

        _prefs.put(MessageConstants.EXTERNAL_PHONE,
                   _externalPhone.getText());

        _prefs.put(MessageConstants.EXTERNAL_FAX, 
                   _faxNumber.getText());

        _prefs.put(MessageConstants.EMAIL_ADDRESS,
                   _emailAddress.getText());

        _prefs.put(MessageConstants.PAGER_TYPE,
                   _pagerType.getSelectedItem());

        _prefs.put(MessageConstants.PAGER_PIN,
                   _pagerPin.getText());

        _prefs.put(MessageConstants.BACKUP_USERID,
                   _backupUserId.getText());

        // Set notification method within preferences
        if(_bPager.isSelected()) {
            _prefs.put(MessageConstants.IMMEDIATE_CONTACT,
                       _bPager.getActionCommand());

        } else if(_bBackup.isSelected()) {
            _prefs.put(MessageConstants.IMMEDIATE_CONTACT,
                       _bBackup.getActionCommand());

        } else if(_bEmail.isSelected()) {
            _prefs.put(MessageConstants.IMMEDIATE_CONTACT,
                       _bEmail.getActionCommand());

        } else if(_bFax.isSelected()) {
            _prefs.put(MessageConstants.IMMEDIATE_CONTACT,
                       _bFax.getActionCommand());

        } else if(_bNone.isSelected()) {
            _prefs.put(MessageConstants.IMMEDIATE_CONTACT,
                       _bNone.getActionCommand());
        }
            
        try {
            // Save the new preferences back to the PreferenceContext           
            _prefs.save();
            
            // Causes the changes to the PreferenceContext to be saved 
            //  back to persistent storage
            _userPrefContext.flush();

        } catch(Exception x) {
            x.printStackTrace();
        }
    }


    /**
     * Obtain the value of the specified user preference.
     * 
     * @param propKey The name of the user preference attribute to look up.
     * @return The value of the user preference if it exists, otherwise a blank.
     */
    String getStringOrBlank(String propKey) {
        try {
            return((String) _prefs.get(propKey));

        } catch(NoPreferenceException x) {
            return("");
        }
    }
}
